;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "cmake-mode" "4.3.2"
  "Major-mode for editing CMake sources."
  '((emacs "24.1"))
  :commit "8d3c68cc0f36108f7ebb23ba7a6bc08b9b1d81e4"
  :revdesc "v4.3.2-0-g8d3c68cc0f36")
